Installation
============

Assuming that you have already have a Django project created,
you can install django_tableaux through the command line with:
    ``pip install django_tableaux``

This will also install django_tableaux's dependencies: django_tables2,
django_filter and django_htmx.Those packages will in turn install
some additional dependencies.


